pub struct RdmaRemoteBuffer {
pub id: usize,
pub size: usize,
pub owner: ActorRef<RdmaManagerActor>,
/* private fields */
}Expand description
Lightweight handle representing a registered RDMA buffer.
Contains an id for the buffer registration, the buffer size, a reference
to the owning RdmaManagerActor, and backend-specific contexts for
performing RDMA operations.
Fields
id: usizesize: usizeowner: ActorRef<RdmaManagerActor>Implementations
Sourceimpl RdmaRemoteBuffer
impl RdmaRemoteBuffer
Sourcepub fn resolve_mlx(
&self,
) -> Option<<IbvBackend<MlxDevice> as RdmaBackend>::RemoteBackendContext>
pub fn resolve_mlx( &self, ) -> Option<<IbvBackend<MlxDevice> as RdmaBackend>::RemoteBackendContext>
Context for this backend, if the buffer advertises it.
Sourcepub fn resolve_efa(
&self,
) -> Option<<IbvBackend<EfaDevice> as RdmaBackend>::RemoteBackendContext>
pub fn resolve_efa( &self, ) -> Option<<IbvBackend<EfaDevice> as RdmaBackend>::RemoteBackendContext>
Context for this backend, if the buffer advertises it.
Sourcepub fn resolve_tcp(
&self,
) -> Option<<TcpBackend as RdmaBackend>::RemoteBackendContext>
pub fn resolve_tcp( &self, ) -> Option<<TcpBackend as RdmaBackend>::RemoteBackendContext>
Context for this backend, if the buffer advertises it.
Sourceimpl RdmaRemoteBuffer
impl RdmaRemoteBuffer
Sourcepub async fn write_from_local(
&self,
client: &(impl Actor + Send + Sync),
local: KeepaliveLocalMemory,
timeout: u64,
) -> Result<bool, Error>
pub async fn write_from_local( &self, client: &(impl Actor + Send + Sync), local: KeepaliveLocalMemory, timeout: u64, ) -> Result<bool, Error>
Push data from local memory into this remote buffer (local->remote).
Sourcepub async fn read_into_local(
&self,
client: &(impl Actor + Send + Sync),
local: KeepaliveLocalMemory,
timeout: u64,
) -> Result<bool, Error>
pub async fn read_into_local( &self, client: &(impl Actor + Send + Sync), local: KeepaliveLocalMemory, timeout: u64, ) -> Result<bool, Error>
Pull data from this remote buffer into local memory (remote->local).